(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     13612,        474]
NotebookOptionsPosition[     11037,        381]
NotebookOutlinePosition[     11383,        396]
CellTagsIndexPosition[     11340,        393]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercise 2: Making a List", "Title",
 CellChangeTimes->{{3.56784526747674*^9, 3.56784527293174*^9}, {
  3.56784542148274*^9, 3.5678454505847397`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellChangeTimes->{{3.56784529211574*^9, 3.5678452958267403`*^9}}],

Cell[TextData[{
 "Lists are a very important idea in ",
 StyleBox["Mathematica. ",
  FontSlant->"Italic"],
 "In other programming languages they might be called arrays. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " you can make a list of any type of object, but most lists are lists of \
numbers. "
}], "Text",
 CellChangeTimes->{{3.56784530499474*^9, 3.56784543154574*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Making Lists", "Subsection",
 CellChangeTimes->{{3.5678454353057404`*^9, 3.56784545429674*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a number of ways of making lists, but in this exercise we will focus \
on two methods: ",
 StyleBox["Range[ ]",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Table[ ]",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.56784545792874*^9, 3.56784551266074*^9}}],

Cell[CellGroupData[{

Cell["Range[ ]", "Subsubsection",
 CellChangeTimes->{{3.56784551661274*^9, 3.56784551950874*^9}}],

Cell[TextData[{
 "In maths we often need to work with lists of whole numbers. Maybe we want \
to find out which numbers are divisible by 3, or maybe we want to find out \
what the numbers from 3 to 23 add up to. \n",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a function called ",
 StyleBox["Range[ ]",
  FontWeight->"Bold"],
 " that will create a list of consecutive numbers. "
}], "Text",
 CellChangeTimes->{{3.56784552648374*^9, 3.5678456418527403`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Range", "[", "10", "]"}]], "Input",
 CellChangeTimes->{{3.56784564422674*^9, 3.56784565079674*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10"}], "}"}]], "Output",
 CellChangeTimes->{3.5678456516357403`*^9}]
}, Open  ]],

Cell[TextData[{
 "As you can see, this has generated a list of all of the integers up to 10. \
Lists always look like this. They are surounded by curly brackets ",
 StyleBox["{ }",
  FontWeight->"Bold"],
 ", and the different elements in the list are separated by commas. \n\n\
Sometimes we may want to specify more exactly which numbers should be in our \
list:"
}], "Text",
 CellChangeTimes->{{3.56784565711574*^9, 3.56784576654874*^9}, 
   3.56784591397974*^9, {3.5678515875385027`*^9, 3.567851588402589*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Range", "[", 
  RowBox[{"3", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.56784576943574*^9, 3.56784578529974*^9}, {
  3.5678514089566464`*^9, 3.5678514132930803`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", ",", "9", ",", 
   "10"}], "}"}]], "Output",
 CellChangeTimes->{{3.5678457788277397`*^9, 3.56784578562774*^9}, {
  3.5678514101987705`*^9, 3.5678514140211525`*^9}}]
}, Open  ]],

Cell[TextData[{
 "As you can see, this makes a list of all of the numbers from 3 to 10. \n\n\
We can also change the",
 StyleBox[" step",
  FontColor->RGBColor[1, 0, 0]],
 ":"
}], "Text",
 CellChangeTimes->{{3.56784579777874*^9, 3.56784581628974*^9}, {
   3.5678514254362946`*^9, 3.5678514374524956`*^9}, 3.567851543697119*^9, 
   3.5678515909948483`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Range", "[", 
  RowBox[{"2", ",", "10", ",", 
   StyleBox["2",
    FontColor->RGBColor[1, 0, 0]]}], "]"}]], "Input",
 CellChangeTimes->{{3.567851439925743*^9, 3.567851457566507*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "4", ",", "6", ",", "8", ",", "10"}], "}"}]], "Output",
 CellChangeTimes->{3.56785157220397*^9}]
}, Open  ]],

Cell["\<\
As the step is now 2, we only get the even numbers.\
\>", "Text",
 CellChangeTimes->{{3.567851464910241*^9, 3.5678514800787582`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Table[ ]", "Subsubsection",
 CellChangeTimes->{{3.56784582185674*^9, 3.56784582544074*^9}}],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " we can use the function ",
 StyleBox["Table[ ]",
  FontWeight->"Bold"],
 " to create more complicated lists. Because the lists are more complicated, \
so is the function. Here is one to create a list of the first 10 square \
numbers: "
}], "Text",
 CellChangeTimes->{{3.567851601058855*^9, 3.5678516205158005`*^9}, {
  3.567851654948243*^9, 3.5678517189666443`*^9}, {3.5678517846812153`*^9, 
  3.5678517875615034`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"x", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5678517220309505`*^9, 3.567851741112859*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "4", ",", "9", ",", "16", ",", "25", ",", "36", ",", "49", ",", 
   "64", ",", "81", ",", "100"}], "}"}]], "Output",
 CellChangeTimes->{3.56785174212796*^9}]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s break that down:\n",
 StyleBox["Table[", "Input"],
 StyleBox["x^2", "Input",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[",", "Input"],
 StyleBox["{x,10}", "Input",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["]\n\n", "Input"],
 "The second, ",
 StyleBox["{x,10}",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[",",
  FontColor->RGBColor[0, 0, 1]],
 " tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that x should be all integers up to 10. ",
 StyleBox["\n", "Input"],
 "The first part, ",
 StyleBox["x^2",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 ", tells ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " that x should be squared. \n\nThe second part works in a similar way to ",
 StyleBox["Range[ ]. ",
  FontWeight->"Bold"],
 "We can tell ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", that we want the 5th to the 10th square numbers like this: "
}], "Text",
 CellChangeTimes->{{3.5678518449232388`*^9, 3.5678518736121073`*^9}, {
  3.567851924734219*^9, 3.5678519663513803`*^9}, {3.567852009313676*^9, 
  3.567852163079051*^9}, {3.5678522178175244`*^9, 3.5678522629700394`*^9}, {
  3.5678522959953413`*^9, 3.5678523010358458`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"x", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "5", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.567852267538496*^9, 3.5678522910038424`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"25", ",", "36", ",", "49", ",", "64", ",", "81", ",", "100"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5678522917489166`*^9}]
}, Open  ]],

Cell["\<\
Or even the first 10 even square numbers: \
\>", "Text",
 CellChangeTimes->{{3.567852328060548*^9, 3.56785236308605*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"x", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "2", ",", "20", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.567852364856227*^9, 3.5678523852952704`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "16", ",", "36", ",", "64", ",", "100", ",", "144", ",", "196", 
   ",", "256", ",", "324", ",", "400"}], "}"}]], "Output",
 CellChangeTimes->{{3.5678523794326844`*^9, 3.567852385865328*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Questions", "Subsection",
 CellChangeTimes->{{3.5678524198087215`*^9, 3.5678524212798686`*^9}}],

Cell[CellGroupData[{

Cell["Question 1", "Subsubsection",
 CellChangeTimes->{{3.567852428656606*^9, 3.5678524318719273`*^9}, {
  3.567852567845524*^9, 3.5678525739571347`*^9}}],

Cell["\<\
Make a list of the first 20 multiples of 3.\
\>", "Text",
 CellChangeTimes->{{3.5678525784535847`*^9, 3.5678526004067793`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.567852604496188*^9, 3.567852604823221*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 2", "Subsubsection",
 CellChangeTimes->{{3.567852610534792*^9, 3.567852613095048*^9}}],

Cell[TextData[{
 StyleBox["Table[ ]",
  FontWeight->"Bold"],
 " can be used with any function. Combine it with ",
 StyleBox["Prime[ ]",
  FontWeight->"Bold"],
 " to make a list of the first 50 prime numbers. "
}], "Text",
 CellChangeTimes->{{3.5678526193506737`*^9, 3.5678526771934576`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.567852678258564*^9, 3.567852678649603*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 3", "Subsubsection",
 CellChangeTimes->{{3.5678526917059083`*^9, 3.567852694154153*^9}}],

Cell["\<\
Make a list of the first 30 Fibonacci numbers. Use the help function if you \
are having trouble. \
\>", "Text",
 CellChangeTimes->{{3.567852807198457*^9, 3.567852854479184*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.56785268192393*^9, 3.5678527000587435`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 4 ", "Subsubsection",
 CellChangeTimes->{{3.567852862255962*^9, 3.567852864576194*^9}, {
  3.5678531291296463`*^9, 3.5678531299617295`*^9}, {3.567853217580491*^9, 
  3.5678532180445375`*^9}}],

Cell[TextData[{
 "The function ",
 StyleBox["Total[ ] ",
  FontWeight->"Bold"],
 "can be used to add up all the numbers in a list. Find the sum of the first \
100 integers"
}], "Text",
 CellChangeTimes->{{3.567853135833317*^9, 3.567853185595292*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.567853189491682*^9, 3.567853214285161*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 5 (*)", "Subsubsection",
 CellChangeTimes->{{3.5678532256612988`*^9, 3.567853233965129*^9}}],

Cell["\<\
Find the total of the divisors of 100.\
\>", "Text",
 CellChangeTimes->{{3.567853237389471*^9, 3.5678532628780203`*^9}, {
  3.5678532967034025`*^9, 3.5678533118079123`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5678532661023426`*^9, 3.5678533422419558`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 6 (*)", "Subsubsection",
 CellChangeTimes->{{3.5678533562093525`*^9, 3.5678533621459455`*^9}}],

Cell["\<\
Make a list of the total of the divisors of each number from 1 to 20.\
\>", "Text",
 CellChangeTimes->{{3.5678533653142624`*^9, 3.5678533939231234`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5678533998027115`*^9, 3.5678534412208524`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{707, 817},
WindowMargins->{{268, Automatic}, {Automatic, 56}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 156, 2, 90, "Title"],
Cell[CellGroupData[{
Cell[760, 28, 101, 1, 43, "Subsection"],
Cell[864, 31, 386, 10, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1287, 46, 101, 1, 43, "Subsection"],
Cell[1391, 49, 342, 12, 49, "Text"],
Cell[CellGroupData[{
Cell[1758, 65, 97, 1, 34, "Subsubsection"],
Cell[1858, 68, 470, 11, 87, "Text"],
Cell[CellGroupData[{
Cell[2353, 83, 123, 2, 31, "Input"],
Cell[2479, 87, 205, 5, 31, "Output"]
}, Open  ]],
Cell[2699, 95, 512, 10, 106, "Text"],
Cell[CellGroupData[{
Cell[3236, 109, 199, 4, 31, "Input"],
Cell[3438, 115, 261, 6, 31, "Output"]
}, Open  ]],
Cell[3714, 124, 355, 9, 68, "Text"],
Cell[CellGroupData[{
Cell[4094, 137, 206, 5, 31, "Input"],
Cell[4303, 144, 145, 3, 31, "Output"]
}, Open  ]],
Cell[4463, 150, 143, 3, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4643, 158, 97, 1, 34, "Subsubsection"],
Cell[4743, 161, 495, 13, 68, "Text"],
Cell[CellGroupData[{
Cell[5263, 178, 223, 6, 31, "Input"],
Cell[5489, 186, 209, 5, 31, "Output"]
}, Open  ]],
Cell[5713, 194, 1235, 38, 163, "Text"],
Cell[CellGroupData[{
Cell[6973, 236, 233, 6, 31, "Input"],
Cell[7209, 244, 167, 4, 31, "Output"]
}, Open  ]],
Cell[7391, 251, 131, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[7547, 258, 243, 6, 31, "Input"],
Cell[7793, 266, 243, 5, 31, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8097, 278, 101, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[8223, 283, 154, 2, 34, "Subsubsection"],
Cell[8380, 287, 137, 3, 30, "Text"],
Cell[8520, 292, 92, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8649, 298, 101, 1, 34, "Subsubsection"],
Cell[8753, 301, 291, 8, 49, "Text"],
Cell[9047, 311, 92, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9176, 317, 103, 1, 34, "Subsubsection"],
Cell[9282, 320, 188, 4, 49, "Text"],
Cell[9473, 326, 93, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9603, 332, 206, 3, 34, "Subsubsection"],
Cell[9812, 337, 250, 7, 49, "Text"],
Cell[10065, 346, 92, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10194, 352, 107, 1, 34, "Subsubsection"],
Cell[10304, 355, 183, 4, 30, "Text"],
Cell[10490, 361, 96, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10623, 367, 109, 1, 34, "Subsubsection"],
Cell[10735, 370, 163, 3, 30, "Text"],
Cell[10901, 375, 96, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
