(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     17826,        547]
NotebookOptionsPosition[     15818,        475]
NotebookOutlinePosition[     16163,        490]
CellTagsIndexPosition[     16120,        487]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercise 6: Manipulate", "Title",
 CellChangeTimes->{{3.571486276676266*^9, 3.571486283827266*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellChangeTimes->{{3.5714862910272665`*^9, 3.5714862936992664`*^9}}],

Cell[TextData[{
 "One of the most powerful and interesting features of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is the ",
 StyleBox["Manipulate[ ] ",
  FontWeight->"Bold"],
 "function. It allows the user to vary any aspect of any other function in \
real time. Here\[CloseCurlyQuote]s a simple example:"
}], "Text",
 CellChangeTimes->{{3.571635813334095*^9, 3.571635822293991*^9}, {
  3.5716358829530563`*^9, 3.571635956827443*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"x", "+", "1"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "20", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571635964672227*^9, 3.5716359899777575`*^9}, {
  3.5716360623039894`*^9, 3.5716360628960485`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`x$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`x$$], 0, 20, 1}}, Typeset`size$$ = {8., {0., 8.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`x$903$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`x$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`x$$, $CellContext`x$903$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> $CellContext`x$$ + 1, 
      "Specifications" :> {{$CellContext`x$$, 0, 20, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{256., {52., 57.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5716359908878484`*^9, 3.5716360634421034`*^9}]
}, Open  ]],

Cell[TextData[{
 "As you can see, the slider allows the user to vary ",
 StyleBox["x",
  FontWeight->"Bold"],
 " from 0 to 20, and then displays the result of the function ",
 StyleBox["x+1.\nManipulate[ ] ",
  FontWeight->"Bold"],
 "can work with any function in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". It is especially useful when combined with the ",
 StyleBox["Plot[ ] ",
  FontWeight->"Bold"],
 "function.\nHere is a very basic ",
 StyleBox["Plot[ ] ",
  FontWeight->"Bold"],
 "of a function: "
}], "Text",
 CellChangeTimes->{{3.5716360758073397`*^9, 3.571636260517809*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"x", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "7"}], ",", "7"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571636263100067*^9, 3.571636318057562*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF1OlPEnAcgHEgUEESlCwpzaPmig11unQeLc0YbiYaBrVcZgjNGYWpMx1q
OVHT2vJCJ8oLj0jHytaW12pamG5a5HJiRgdl4pWVKJO8qLb4/l48+/wHj7dA
whXhMBhM3N/+WTAbZ7JaaQM2jdLdZv0mkkP9vNb9G+kVmrElWUG+qKh2MBiR
Dn6T+wdeI2uzU2JvNiLV2Kw2TAiSIGIH0s+7gLR3L8UtVc4gV6NIPTxCBaU/
j4orpylgz3VFeme8E8ip5nltN5BBtvIZJ+Y7CVQN5+mykohgsqzW9U27PViY
suOhI80OxDA9+6NL8OD72w1l6gkc6E5K61g9jgUvH2EQ9O7WfpupIZ/aNZoN
kJEbZr3aZgGbPyYO5kWZwdki1wi2mwnskx9izfGXwID5qVV/pRE80acnbvEN
YEZHp8WZNg7yLx1ofpvfCw6/mqoISuw5ZjOM+fxxQv04iMtx/SCkG0B7ckKR
4IcRLDboojNbl8BHjaUJhaZlUNIipH7jm8HkdIVHWZEFLD+VExrUtAHid8mN
N9a3wcnRkl8yCjbSJk8qCFZocKDYcdFHew4PeqqH6uwWCKC0JzqR0mgPZqjE
XcH+RJCMCxH4zZBA1pXTckYNGXTr9ZCwDjqB1Zm3qgImKSC3NJ6p7KKCjCQZ
r63AGdQZiS01PBdQK5iJcvGkgV/w9y1yH+SqKq2T7oukLy66ezORwizTmn84
cr3Y+iDuDNL3Hn1v+V1kKFs/Rq5BnpxvKqusQ15jepnrlcinT3zHVGokdyio
dHAYKUozR8SMInNJ3SujWqSSE3ZxfAI5p4uM+DqNXM/FrYhmkTv3DXbMLyAD
L7D3LC8jWViiNtuMPNs6IrNYkOmsO+H5m8j/3wL/ABUIQAk=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{-5, 5}, {-7, 7}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.5716363186656227`*^9}]
}, Open  ]],

Cell[TextData[{
 "I have locked the ",
 StyleBox["PlotRange ",
  FontWeight->"Bold"],
 "to -7 to 7, so that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " doesn\[CloseCurlyQuote]t automatically resize the graphs.\nWe can use ",
 StyleBox["Manipulate[ ] ",
  FontWeight->"Bold"],
 "to see what effect adding a constant has:"
}], "Text",
 CellChangeTimes->{{3.571636342553012*^9, 3.571636369161672*^9}, {
  3.571637199302016*^9, 3.571637239827016*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"x", "+", "c"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "7"}], ",", "7"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "0", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.571636371488905*^9, 3.571636394665222*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 0., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`c$$], 0, 4}}, Typeset`size$$ = {360., {109., 114.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`c$1192$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`c$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$1192$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[$CellContext`x + $CellContext`c$$, {$CellContext`x, -5, 5}, 
        PlotRange -> {-7, 7}], "Specifications" :> {{$CellContext`c$$, 0, 4}},
       "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {156., 161.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5716363953722925`*^9}]
}, Open  ]],

Cell[TextData[{
 "This allows the user to vary the constant from 0 to 4, and view the results \
immediately on the graph. \n",
 StyleBox["Manipulate[ ] ",
  FontWeight->"Bold"],
 "can be used with any number of variables. Let\[CloseCurlyQuote]s add the \
ability to change the gradient, ",
 StyleBox["m ",
  FontWeight->"Bold"],
 "as well. "
}], "Text",
 CellChangeTimes->{{3.5716364130200577`*^9, 3.57163646514927*^9}, {
  3.571637169368016*^9, 3.571637193462016*^9}, {3.571637244547016*^9, 
  3.571637272113016*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"m", " ", "x"}], "+", "c"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "7"}], ",", "7"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "0", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5716364092696824`*^9, 3.5716364107488303`*^9}, {
  3.571637279426016*^9, 3.571637291025016*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = 2.79, $CellContext`m$$ = 
    0.7000000000000002, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`c$$], 0, 4}, {
      Hold[$CellContext`m$$], -2, 2}}, Typeset`size$$ = {360., {109., 114.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`c$391$$ = 0, $CellContext`m$392$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c$$ = 0, $CellContext`m$$ = -2}, 
      "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$391$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$392$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Plot[$CellContext`m$$ $CellContext`x + $CellContext`c$$, \
{$CellContext`x, -5, 5}, PlotRange -> {-7, 7}], 
      "Specifications" :> {{$CellContext`c$$, 0, 4}, {$CellContext`m$$, -2, 
         2}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{411., {170., 175.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5716372943030157`*^9}]
}, Open  ]],

Cell["\<\
As you can see, this creates 2 sliders, which the user can manipulate \
independently.\
\>", "Text",
 CellChangeTimes->{{3.571637313327016*^9, 3.5716373348450155`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Questions", "Subsection",
 CellChangeTimes->{{3.5716373816910157`*^9, 3.571637387226016*^9}}],

Cell[CellGroupData[{

Cell["Question 1", "Subsubsection",
 CellChangeTimes->{{3.571637391226016*^9, 3.5716373942170157`*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Manipulate[ ] ",
  FontWeight->"Bold"],
 "to make an interactivity which allows the user to vary ",
 StyleBox["x",
  FontWeight->"Bold"],
 " from 0 to 10 in steps of 1, and displays ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], "+", "3"}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5716374004250154`*^9, 3.5716374986140156`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5716375027670155`*^9, 3.5716375040990157`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 2", "Subsubsection",
 CellChangeTimes->{{3.5716375090740156`*^9, 3.5716375110260158`*^9}}],

Cell[TextData[{
 "Create an interactive graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], "+", "c"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", where ",
 StyleBox["c",
  FontWeight->"Bold"],
 " can vary from -3 to 3. Don\[CloseCurlyQuote]t forget to lock the size of \
the graph using ",
 StyleBox["PlotRange.",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.571637524657016*^9, 3.571637627179016*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.571637629332016*^9, 3.5716376302510157`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 3", "Subsubsection",
 CellChangeTimes->{{3.571637635146016*^9, 3.571637637802016*^9}}],

Cell[TextData[{
 "Modify your graph to create an interactive graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "2"], "+", "bx", " ", "+", "c"}], TraditionalForm]]],
 ", where ",
 StyleBox["b ",
  FontWeight->"Bold"],
 "can also vary from -3 to 3."
}], "Text",
 CellChangeTimes->{{3.571637655865016*^9, 3.5716377393038883`*^9}, {
  3.571637918481804*^9, 3.5716379230862646`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5716377404179993`*^9, 3.571637741577115*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 4", "Subsubsection",
 CellChangeTimes->{{3.5716377514491024`*^9, 3.5716377544244003`*^9}}],

Cell[TextData[{
 "Modify your graph again to create an interactive graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["ax", "2"], "+", "bx", " ", "+", "c"}], TraditionalForm]]],
 ", where ",
 StyleBox["a ",
  FontWeight->"Bold"],
 "can also vary from -3 to 3. Describe what each of these parts of a \
quadratic does to the shape and position of the graph."
}], "Text",
 CellChangeTimes->{{3.571637776346592*^9, 3.5716378407800345`*^9}, {
  3.5716381692108746`*^9, 3.571638170507004*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5716377679217496`*^9, 3.571637771978155*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 5 (*)", "Subsubsection",
 CellChangeTimes->{{3.571637848011758*^9, 3.5716378560925655`*^9}}],

Cell[TextData[{
 "Use the documentation centre to find out how to set an initial value for a \
variable in ",
 StyleBox["Manipulate[ ]. ",
  FontWeight->"Bold"],
 "Use this to set ",
 StyleBox["a",
  FontWeight->"Bold"],
 ", ",
 StyleBox["b",
  FontWeight->"Bold"],
 " and ",
 StyleBox["c",
  FontWeight->"Bold"],
 " to all start at 1."
}], "Text",
 CellChangeTimes->{{3.571637868204777*^9, 3.5716379389908547`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5716379522011757`*^9, 3.5716379529762535`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 6 (**)", "Subsubsection",
 CellChangeTimes->{{3.5716379908810434`*^9, 3.571637996497605*^9}, 
   3.5716381363905926`*^9}],

Cell[TextData[{
 "Create an interactive graph of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "3"], "+", 
    SuperscriptBox["ax", "2"], "+", "bx", " ", "+", "c"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", where ",
 StyleBox["a",
  FontWeight->"Bold"],
 ", ",
 StyleBox["b",
  FontWeight->"Bold"],
 " and ",
 StyleBox["c",
  FontWeight->"Bold"],
 " can vary from -4 to 4. Use it to find a cubic graph which crosses the \
x-axis at 0,1 and 2. You can use the little + buttons next to the sliders to \
see exact values and more options. "
}], "Text",
 CellChangeTimes->{{3.57163798254521*^9, 3.5716380188338385`*^9}, {
  3.571638133414295*^9, 3.5716382065846114`*^9}, {3.571638501891139*^9, 
  3.571638601991148*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.571638210144967*^9, 3.5716382978537374`*^9}, 
   3.5716385229972496`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{707, 817},
WindowMargins->{{24, Automatic}, {Automatic, 30}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 105, 1, 90, "Title"],
Cell[CellGroupData[{
Cell[709, 27, 104, 1, 43, "Subsection"],
Cell[816, 30, 446, 11, 68, "Text"],
Cell[CellGroupData[{
Cell[1287, 45, 301, 7, 31, "Input"],
Cell[1591, 54, 1501, 31, 126, "Output"]
}, Open  ]],
Cell[3107, 88, 595, 18, 106, "Text"],
Cell[CellGroupData[{
Cell[3727, 110, 347, 10, 31, "Input"],
Cell[4077, 122, 1309, 28, 238, "Output"]
}, Open  ]],
Cell[5401, 153, 458, 13, 68, "Text"],
Cell[CellGroupData[{
Cell[5884, 170, 509, 15, 31, "Input"],
Cell[6396, 187, 1555, 32, 334, "Output"]
}, Open  ]],
Cell[7966, 222, 518, 13, 87, "Text"],
Cell[CellGroupData[{
Cell[8509, 239, 679, 20, 52, "Input"],
Cell[9191, 261, 1795, 36, 362, "Output"]
}, Open  ]],
Cell[11001, 300, 178, 4, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11216, 309, 99, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[11340, 314, 103, 1, 34, "Subsubsection"],
Cell[11446, 317, 434, 14, 51, "Text"],
Cell[11883, 333, 96, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12016, 339, 105, 1, 34, "Subsubsection"],
Cell[12124, 342, 456, 15, 51, "Text"],
Cell[12583, 359, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12714, 365, 101, 1, 34, "Subsubsection"],
Cell[12818, 368, 402, 12, 51, "Text"],
Cell[13223, 382, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13354, 388, 105, 1, 34, "Subsubsection"],
Cell[13462, 391, 505, 13, 70, "Text"],
Cell[13970, 406, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14101, 412, 107, 1, 34, "Subsubsection"],
Cell[14211, 415, 416, 16, 49, "Text"],
Cell[14630, 433, 96, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14763, 439, 136, 2, 34, "Subsubsection"],
Cell[14902, 443, 751, 23, 70, "Text"],
Cell[15656, 468, 122, 2, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
