(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     17961,        618]
NotebookOptionsPosition[     15010,        513]
NotebookOutlinePosition[     15353,        528]
CellTagsIndexPosition[     15310,        525]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercise 7- Functions", "Title",
 CellChangeTimes->{{3.5726795382155094`*^9, 3.572679545031191*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellChangeTimes->{{3.572679548760564*^9, 3.572679554008088*^9}}],

Cell[CellGroupData[{

Cell["Built in Functions", "Subsubsection",
 CellChangeTimes->{{3.572679565257213*^9, 3.5726795706807556`*^9}}],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a functional programming language. That means that learning about how \
functions work is very important. You have met several functions already, and \
one of the best things about ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is that these are clearly named and (quite) easy to use. For example ",
 StyleBox["Range[ ] ",
  FontWeight->"Bold"],
 "is a function:"
}], "Text",
 CellChangeTimes->{{3.572680057359027*^9, 3.5726801875260267`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Range", "[", "10", "]"}]], "Input",
 CellChangeTimes->{{3.5726801890720267`*^9, 3.572680192055027*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8", 
   ",", "9", ",", "10"}], "}"}]], "Output",
 CellChangeTimes->{3.572680192654027*^9}]
}, Open  ]],

Cell[TextData[{
 "Functions always have a name, in this case ",
 StyleBox["Range, ",
  FontWeight->"Bold"],
 "and one or more ",
 StyleBox["arguments",
  FontWeight->"Bold"],
 ". In this case we have give ",
 StyleBox["Range ",
  FontWeight->"Bold"],
 "the argument ",
 StyleBox["10. Arguments ",
  FontWeight->"Bold"],
 "tell the function what numbers to work with.\nSome functions have more than \
one ",
 StyleBox["argument",
  FontWeight->"Bold"],
 ". ",
 StyleBox["Table[ ] ",
  FontWeight->"Bold"],
 "for example, has at least 2:"
}], "Text",
 CellChangeTimes->{{3.5726802094570265`*^9, 3.5726802239880266`*^9}, {
  3.572680316510027*^9, 3.572680329277027*^9}, {3.572680455909027*^9, 
  3.5726805068980265`*^9}, {3.572680548959027*^9, 3.5726806517050266`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"x", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5726806535660267`*^9, 3.5726806747100267`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9", ",", "16", ",", "25"}], "}"}]], "Output",
 CellChangeTimes->{3.572680675215027*^9}]
}, Open  ]],

Cell[TextData[{
 "The first ",
 StyleBox["argument ",
  FontWeight->"Bold"],
 "here is ",
 StyleBox["x^2, ",
  FontWeight->"Bold"],
 "and the second is ",
 StyleBox["{x,1,5}. ",
  FontWeight->"Bold"],
 "Notice that the ",
 StyleBox["arguments ",
  FontWeight->"Bold"],
 "are separated by a comma.\n",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s in-built functions always have capitalised names. When \
we create our own functions below, we will use lower case letters, so we don\
\[CloseCurlyQuote]t get confused."
}], "Text",
 CellChangeTimes->{{3.572680680359027*^9, 3.572680700213027*^9}, {
  3.572680736499027*^9, 3.5726808499640265`*^9}, {3.5726830647430215`*^9, 
  3.5726830686470213`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make your own Functions", "Subsubsection",
 CellChangeTimes->{{3.5726795784405317`*^9, 3.5726795972894163`*^9}}],

Cell[TextData[{
 "Even though ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " comes with 1000s of built in functions, sometimes we will have to make our \
own.\nWe want to make the function ",
 StyleBox["f[x] = x^2 + 2x + 1 ",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5726827737540216`*^9, 3.5726828076880217`*^9}, {
  3.5726829338240213`*^9, 3.5726829682060213`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"x", "^", "2"}], "+", 
   RowBox[{"2", "x"}], "+", "1"}]}]], "Input",
 CellChangeTimes->{{3.572682975573022*^9, 3.5726829869730215`*^9}}],

Cell["\<\
This is a pretty simple function, but there are a lot of new things here. \
First, let\[CloseCurlyQuote]s test it:\
\>", "Text",
 CellChangeTimes->{{3.572683043929022*^9, 3.572683051592022*^9}, {
  3.5726831174120216`*^9, 3.5726831578410215`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "2", "]"}]], "Input",
 CellChangeTimes->{{3.5726843303821154`*^9, 3.572684331334211*^9}}],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.572684332033281*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5726831635300217`*^9, 3.5726831646260214`*^9}, {
  3.572683533962022*^9, 3.572683545193022*^9}, {3.572684306964774*^9, 
  3.572684320374115*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "4", ",", "9", ",", "16", ",", "25", ",", "36"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5726831656890216`*^9, 3.572683545988022*^9, 
  3.572684320942172*^9}]
}, Open  ]],

Cell[TextData[{
 "Seems right! On the right hand side of the function, we have the \
definition. On the left hand side we have ",
 StyleBox["f[x_]. ",
  FontWeight->"Bold"],
 "That line next to the x is called an underscore, or a blank. We use this to \
tell ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to look out for an ",
 StyleBox["argument, ",
  FontWeight->"Bold"],
 "and to call it ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". In the middle, instead of the usual ",
 StyleBox["=",
  FontWeight->"Bold"],
 " sign, we have ",
 StyleBox[":=",
  FontWeight->"Bold"],
 ". This is important, but we will talk about that in a future exercise.\n\n\
While working with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", you have met a type of function called a ",
 StyleBox["Q Function. ",
  FontWeight->"Bold"],
 "These are functions which test numbers. F or example you have met, ",
 StyleBox["OddQ, EvenQ ",
  FontWeight->"Bold"],
 "and ",
 StyleBox["PrimeQ, ",
  FontWeight->"Bold"],
 "which check if a number is odd, even or prime, respectively.  \nWe will \
make a Q function to test if a number is divisible by 3. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has a function for testing divisibilty, it is called ",
 StyleBox["Divisible[ ]",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5726833878590217`*^9, 3.5726835139790215`*^9}, {
   3.5726836000370216`*^9, 3.57268388258134*^9}, {3.572684020458126*^9, 
   3.5726840232584066`*^9}, 3.5726892916116185`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Divisible", "[", 
  RowBox[{"6", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.5726838891179934`*^9, 3.5726838988069625`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.572683899341016*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Divisible", "[", 
  RowBox[{"7", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.5726839020842905`*^9, 3.5726839085669384`*^9}}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.5726839090369854`*^9}]
}, Open  ]],

Cell["\<\
We will use this to create our own function:\
\>", "Text",
 CellChangeTimes->{{3.572683916630745*^9, 3.572683931271209*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"divby3Q", "[", "x_", "]"}], ":=", " ", 
  RowBox[{"Divisible", "[", 
   RowBox[{"x", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5726839346085424`*^9, 3.572683955320613*^9}, 
   3.572684152992378*^9}],

Cell["First, let\[CloseCurlyQuote]s test it:", "Text",
 CellChangeTimes->{{3.5726839838494663`*^9, 3.5726839897050514`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divby3Q", "[", "6", "]"}]], "Input",
 CellChangeTimes->{{3.5726839922913103`*^9, 3.572683997529834*^9}, 
   3.572684155983678*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5726839981928997`*^9, 3.5726841622633057`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divby3Q", "[", "7", "]"}]], "Input",
 CellChangeTimes->{{3.5726839999580765`*^9, 3.5726840033064117`*^9}, 
   3.572684158687948*^9}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.572684004112492*^9, 3.5726841641514945`*^9}]
}, Open  ]],

Cell[TextData[{
 "Seems ok! It works in the same way as the ",
 StyleBox["f[x] ",
  FontWeight->"Bold"],
 "function we designed above. We have used a lower case letter at the start \
of the name, to remind ourselves that it is not a built-in function. \nWe can \
use our new function anywhere:"
}], "Text",
 CellChangeTimes->{{3.572684062667347*^9, 3.5726842058886676`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Range", "[", "100", "]"}], ",", "divby3Q"}], "]"}]], "Input",
 CellChangeTimes->{{3.572684208665945*^9, 3.572684241796258*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "6", ",", "9", ",", "12", ",", "15", ",", "18", ",", "21", ",", 
   "24", ",", "27", ",", "30", ",", "33", ",", "36", ",", "39", ",", "42", 
   ",", "45", ",", "48", ",", "51", ",", "54", ",", "57", ",", "60", ",", 
   "63", ",", "66", ",", "69", ",", "72", ",", "75", ",", "78", ",", "81", 
   ",", "84", ",", "87", ",", "90", ",", "93", ",", "96", ",", "99"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5726842319292717`*^9, 3.572684242346313*^9}}]
}, Open  ]],

Cell["\<\
This has selected all the numbers between 1 and 100 which are divisible by 3.\
\>", "Text",
 CellChangeTimes->{{3.5726842588829665`*^9, 3.5726842770117793`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Questions", "Subsection",
 CellChangeTimes->{{3.572689746246005*^9, 3.5726897522140045`*^9}}],

Cell[CellGroupData[{

Cell["Question 1", "Subsubsection",
 CellChangeTimes->{{3.572689756150005*^9, 3.572689761621005*^9}}],

Cell[TextData[{
 "Create the function ",
 StyleBox["g[x] = 2x^2 + 7x -5",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.572690011781005*^9, 3.5726900490110044`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5726900720110044`*^9, 3.5726900729620047`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 2", "Subsubsection",
 CellChangeTimes->{{3.5726900792970047`*^9, 3.572690083552005*^9}}],

Cell[TextData[{
 "Use your function to make a ",
 StyleBox["Table ",
  FontWeight->"Bold"],
 "of the values of ",
 StyleBox["g[x] ",
  FontWeight->"Bold"],
 "from ",
 StyleBox["x=0 ",
  FontWeight->"Bold"],
 "to ",
 StyleBox["x=10",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5726900892000046`*^9, 3.572690145564005*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5726901472700047`*^9, 3.5726901476930046`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 3", "Subsubsection",
 CellChangeTimes->{{3.572690150940005*^9, 3.5726901528760047`*^9}}],

Cell[TextData[{
 "Create a function called ",
 StyleBox["divby7Q[ ]",
  FontWeight->"Bold"],
 ", which tests if a number is divisible by 7. Use your function to ",
 StyleBox["Select",
  FontWeight->"Bold"],
 " a list of all numbers below 1000 which are divisible by 7."
}], "Text",
 CellChangeTimes->{{3.5726901770820045`*^9, 3.5726901878820047`*^9}, {
  3.572690556722005*^9, 3.572690622046005*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.572690623111005*^9, 3.572690623486005*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 4 (*)", "Subsubsection",
 CellChangeTimes->{{3.572690628397005*^9, 3.572690648796005*^9}}],

Cell[TextData[{
 "Find the number of positive integers ",
 StyleBox["0 < n < 20000",
  FontWeight->"Bold"],
 " such that 1997 divides ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "2"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "+",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], "2"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". Try the same code with 2013."
}], "Text",
 CellChangeTimes->{{3.572691101039005*^9, 3.572691214584005*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.572691371111005*^9, 3.5726913714870048`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 5 (*)", "Subsubsection",
 CellChangeTimes->{{3.572691478551005*^9, 3.572691484166005*^9}}],

Cell[TextData[{
 "Make a function ",
 StyleBox["triangle[n], ",
  FontWeight->"Bold"],
 "which calculates the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "th"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " triangular number. (See: ",
 Cell[BoxData[
  TagBox[
   ButtonBox[
    PaneSelectorBox[{False->"\<\"Wikipedia\"\>", True->
     StyleBox["\<\"Wikipedia\"\>", "HyperlinkActive"]}, Dynamic[
      CurrentValue["MouseOver"]],
     BaseStyle->{"Hyperlink"},
     FrameMargins->0,
     ImageSize->Automatic],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://en.wikipedia.org/wiki/Triangular_number"], None},
    ButtonNote->"http://en.wikipedia.org/wiki/Triangular_number"],
   Annotation[#, "http://en.wikipedia.org/wiki/Triangular_number", 
    "Hyperlink"]& ]],
  CellChangeTimes->{3.5726917470090046`*^9}],
 ")"
}], "Text",
 CellChangeTimes->{{3.572691488374005*^9, 3.5726916780600047`*^9}, {
  3.5726917523650045`*^9, 3.572691754805005*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.572691766796005*^9, 3.5726917676850047`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 6 (**)", "Subsubsection",
 CellChangeTimes->{{3.5726917741390047`*^9, 3.5726917839710045`*^9}}],

Cell[TextData[{
 "Use this function, and the ",
 StyleBox["Divisors[ ] ",
  FontWeight->"Bold"],
 "function,",
 StyleBox[" ",
  FontWeight->"Bold"],
 "to solve ",
 Cell[BoxData[
  TagBox[
   ButtonBox[
    PaneSelectorBox[{False->"\<\"Problem 12 on Project Euler\"\>", True->
     StyleBox["\<\"Problem 12 on Project Euler\"\>", "HyperlinkActive"]}, 
     Dynamic[
      CurrentValue["MouseOver"]],
     BaseStyle->{"Hyperlink"},
     FrameMargins->0,
     ImageSize->Automatic],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["http://projecteuler.net/problem=12"], None},
    ButtonNote->"http://projecteuler.net/problem=12"],
   Annotation[#, "http://projecteuler.net/problem=12", "Hyperlink"]& ]],
  CellChangeTimes->{3.572691886135005*^9}],
 "."
}], "Text",
 CellChangeTimes->{{3.572691794682005*^9, 3.572691851519005*^9}, {
  3.5726918917590046`*^9, 3.572691899484005*^9}, {3.5726919305746536`*^9, 
  3.572691989558448*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.572691908724284*^9, 3.5726919110207434`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{707, 817},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 106, 1, 90, "Title"],
Cell[CellGroupData[{
Cell[710, 27, 100, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[835, 32, 111, 1, 34, "Subsubsection"],
Cell[949, 35, 522, 13, 87, "Text"],
Cell[CellGroupData[{
Cell[1496, 52, 127, 2, 31, "Input"],
Cell[1626, 56, 203, 5, 31, "Output"]
}, Open  ]],
Cell[1844, 64, 766, 24, 87, "Text"],
Cell[CellGroupData[{
Cell[2635, 92, 234, 6, 31, "Input"],
Cell[2872, 100, 147, 3, 31, "Output"]
}, Open  ]],
Cell[3034, 106, 723, 22, 87, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3794, 133, 118, 1, 34, "Subsubsection"],
Cell[3915, 136, 390, 10, 68, "Text"],
Cell[4308, 148, 223, 6, 31, "Input"],
Cell[4534, 156, 257, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[4816, 165, 122, 2, 31, "Input"],
Cell[4941, 169, 70, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5048, 175, 337, 8, 31, "Input"],
Cell[5388, 185, 210, 5, 31, "Output"]
}, Open  ]],
Cell[5613, 193, 1502, 44, 201, "Text"],
Cell[CellGroupData[{
Cell[7140, 241, 155, 3, 31, "Input"],
Cell[7298, 246, 73, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7408, 252, 155, 3, 31, "Input"],
Cell[7566, 257, 76, 1, 31, "Output"]
}, Open  ]],
Cell[7657, 261, 134, 3, 30, "Text"],
Cell[7794, 266, 244, 6, 31, "Input"],
Cell[8041, 274, 124, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[8190, 279, 154, 3, 31, "Input"],
Cell[8347, 284, 99, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8483, 290, 156, 3, 31, "Input"],
Cell[8642, 295, 98, 1, 31, "Output"]
}, Open  ]],
Cell[8755, 299, 374, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[9154, 311, 189, 4, 31, "Input"],
Cell[9346, 317, 503, 9, 52, "Output"]
}, Open  ]],
Cell[9864, 329, 171, 3, 30, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10084, 338, 99, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[10208, 343, 101, 1, 34, "Subsubsection"],
Cell[10312, 346, 175, 5, 30, "Text"],
Cell[10490, 353, 96, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10623, 359, 103, 1, 34, "Subsubsection"],
Cell[10729, 362, 334, 14, 30, "Text"],
Cell[11066, 378, 96, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11199, 384, 103, 1, 34, "Subsubsection"],
Cell[11305, 387, 400, 10, 49, "Text"],
Cell[11708, 399, 92, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11837, 405, 105, 1, 34, "Subsubsection"],
Cell[11945, 408, 521, 18, 51, "Text"],
Cell[12469, 428, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12600, 434, 105, 1, 34, "Subsubsection"],
Cell[12708, 437, 980, 29, 33, "Text"],
Cell[13691, 468, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13822, 474, 110, 1, 34, "Subsubsection"],
Cell[13935, 477, 938, 28, 31, "Text"],
Cell[14876, 507, 94, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
