(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     19663,        683]
NotebookOptionsPosition[     16005,        555]
NotebookOutlinePosition[     16351,        570]
CellTagsIndexPosition[     16308,        567]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Pure Functions", "Title",
 CellChangeTimes->{{3.5770773710845413`*^9, 3.577077374555889*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellChangeTimes->{{3.577078618066186*^9, 3.577078623457725*^9}}],

Cell[TextData[{
 "As we have said before, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is a functional language, and so functions are very important in it. \
Sometimes we might wish to define our own functions, such as one to find out \
if a number is divisible by 3:"
}], "Text",
 CellChangeTimes->{{3.577077380348468*^9, 3.5770774833757696`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"divBy3Q", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Mod", "[", 
    RowBox[{"x", ",", "3"}], "]"}], "\[Equal]", "0"}]}]], "Input",
 CellChangeTimes->{{3.577077488254257*^9, 3.5770775157620077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divBy3Q", "[", "6", "]"}]], "Input",
 CellChangeTimes->{{3.5770775177822104`*^9, 3.577077521121544*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.577077521565588*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divBy3Q", "[", "7", "]"}]], "Input",
 CellChangeTimes->{{3.5770775260090322`*^9, 3.577077532658697*^9}}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.577077533115743*^9}]
}, Open  ]],

Cell[TextData[{
 "You have seen this syntax before. \nSometimes, though, you may wish to use \
a function only once, and in this case it is a lot of work to define a whole \
new function. If this happens, it is better to use a ",
 StyleBox["Pure Function.\n",
  FontWeight->"Bold"],
 "The ",
 StyleBox["Pure Function ",
  FontWeight->"Bold"],
 "equivalent of our ",
 StyleBox["divBy3[ ] ",
  FontWeight->"Bold"],
 "function is:"
}], "Text",
 CellChangeTimes->{{3.577077538994331*^9, 3.577077625888912*^9}, {
  3.577077823700912*^9, 3.577077886847912*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Mod", "[", 
    RowBox[{"#", ",", "3"}], "]"}], "\[Equal]", "0"}], "&"}]], "Input",
 CellChangeTimes->{{3.5770776327909117`*^9, 3.577077705036912*^9}, {
  3.577077775255912*^9, 3.577077783383912*^9}, {3.577077813685912*^9, 
  3.577077814197912*^9}}],

Cell[TextData[{
 "As you can see, the x has been replaced with ",
 StyleBox["#",
  FontWeight->"Bold"],
 " (on the right of your keyboard), and an ",
 StyleBox["&",
  FontWeight->"Bold"],
 " (above the 7) has been added to the end.\nWe can use a pure function like \
this:"
}], "Text",
 CellChangeTimes->{{3.5770778897029123`*^9, 3.577077900463912*^9}, {
  3.577078406938075*^9, 3.5770784859489756`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Mod", "[", 
     RowBox[{"#", ",", "3"}], "]"}], "\[Equal]", "0"}], "&"}], "[", "6", 
  "]"}]], "Input",
 CellChangeTimes->{{3.5770784937417545`*^9, 3.5770784951178923`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5770784957499557`*^9}]
}, Open  ]],

Cell[TextData[{
 "The most common uses, however are with ",
 StyleBox["lists.",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770785634077206`*^9, 3.577078600273407*^9}}],

Cell[CellGroupData[{

Cell["Searching Lists", "Subsubsection",
 CellChangeTimes->{{3.5770786287862577`*^9, 3.5770786349138703`*^9}}],

Cell[TextData[{
 "You have seen the ",
 StyleBox["Select[ ] ",
  FontWeight->"Bold"],
 "function before. It allows you to pick out elements from a list which match \
a certain criteria. For example, to find the numbers under 100 which are \
divisible by 5, we would previously have defined the function ",
 StyleBox["divBy5Q[ ]:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770786082092004`*^9, 3.5770786096013393`*^9}, {
  3.577078646451024*^9, 3.577078704084787*^9}, {3.577078761175495*^9, 
  3.5770788211614933`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"divBy5Q", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Mod", "[", 
    RowBox[{"x", ",", "5"}], "]"}], "\[Equal]", "0"}]}]], "Input",
 CellChangeTimes->{{3.5770788230736847`*^9, 3.5770788449068675`*^9}}],

Cell[TextData[{
 "Then used ",
 StyleBox["Select[ ]:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770788477641535`*^9, 3.5770788706184387`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Range", "[", "100", "]"}], ",", "divBy5Q"}], "]"}]], "Input",
 CellChangeTimes->{{3.577078872899667*^9, 3.577078887660143*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "10", ",", "15", ",", "20", ",", "25", ",", "30", ",", "35", ",", 
   "40", ",", "45", ",", "50", ",", "55", ",", "60", ",", "65", ",", "70", 
   ",", "75", ",", "80", ",", "85", ",", "90", ",", "95", ",", "100"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5770788880681834`*^9}]
}, Open  ]],

Cell[TextData[{
 "Now, however, we can do this in only one step, using a ",
 StyleBox["Pure Function:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.577078895755952*^9, 3.5770789203804145`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{
   RowBox[{"Range", "[", "100", "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"#", ",", "5"}], "]"}], "\[Equal]", "0"}], "&"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.577078922565633*^9, 3.577078948574233*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "10", ",", "15", ",", "20", ",", "25", ",", "30", ",", "35", ",", 
   "40", ",", "45", ",", "50", ",", "55", ",", "60", ",", "65", ",", "70", 
   ",", "75", ",", "80", ",", "85", ",", "90", ",", "95", ",", "100"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.577078942260602*^9, 3.5770789489022665`*^9}}]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["Pure Function, Mod[#,5]\[Equal]0 &, ",
  FontWeight->"Bold"],
 "is written straight into the criteria slot. The ",
 StyleBox["Select[ ] ",
  FontWeight->"Bold"],
 "function then tests each number from 1 to 100, and keeps the ones where the \
function is true."
}], "Text",
 CellChangeTimes->{{3.5770789552779036`*^9, 3.577079083266701*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Applying a Function to a List", "Subsubsection",
 CellChangeTimes->{{3.577079091186493*^9, 3.5770791022906036`*^9}}],

Cell["\<\
We have seen that we can make a list, and then apply a function to it, for \
example:\
\>", "Text",
 CellChangeTimes->{{3.5770793650586576`*^9, 3.577079421493658*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Range", "[", "10", "]"}], "^", "2"}]], "Input",
 CellChangeTimes->{{3.5770794069916577`*^9, 3.577079412486658*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "4", ",", "9", ",", "16", ",", "25", ",", "36", ",", "49", ",", 
   "64", ",", "81", ",", "100"}], "}"}]], "Output",
 CellChangeTimes->{3.577079412911658*^9}]
}, Open  ]],

Cell[TextData[{
 "Applies the squaring function to the first 10 numbers, giving the first 10 \
square numbers. What would happen, though, if we needed to apply a more \
complicated function, like ",
 StyleBox["x^3 - 3x^2 + 2",
  FontWeight->"Bold"],
 "? We could use a ",
 StyleBox["Table[ ]:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770794244986577`*^9, 3.5770795804916577`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", "3"}], "-", 
    RowBox[{"3", 
     RowBox[{"x", "^", "2"}]}], "+", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "1", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.577079582180658*^9, 3.577079601003658*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "2"}], ",", "2", ",", "18", ",", "52", ",", "110", ",", "198",
    ",", "322", ",", "488", ",", "702"}], "}"}]], "Output",
 CellChangeTimes->{3.5770796018416576`*^9}]
}, Open  ]],

Cell["\<\
We could define the function, then apply it to the list:\
\>", "Text",
 CellChangeTimes->{{3.577079608646658*^9, 3.577079637015658*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"x", "^", "3"}], "-", 
   RowBox[{"3", 
    RowBox[{"x", "^", "2"}]}], "+", "2"}]}]], "Input",
 CellChangeTimes->{{3.577079639201658*^9, 3.5770796586316576`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"Range", "[", "10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5770802617876577`*^9, 3.5770802732636576`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "2"}], ",", "2", ",", "18", ",", "52", ",", "110", ",", "198",
    ",", "322", ",", "488", ",", "702"}], "}"}]], "Output",
 CellChangeTimes->{{3.577080267087658*^9, 3.5770802737846575`*^9}}]
}, Open  ]],

Cell[TextData[{
 "Or we can use a ",
 StyleBox["Pure Function:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770802533606577`*^9, 3.577080257455658*^9}, {
  3.577080294653658*^9, 3.577080306972658*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"#", "^", "3"}], "-", 
    RowBox[{"3", 
     RowBox[{"#", "^", "2"}]}], "+", "2"}], "&"}], "/@", 
  RowBox[{"Range", "[", "10", "]"}]}]], "Input",
 CellChangeTimes->{{3.577080324364658*^9, 3.577080342955658*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", "2"}], ",", "2", ",", "18", ",", "52", ",", "110", ",", "198",
    ",", "322", ",", "488", ",", "702"}], "}"}]], "Output",
 CellChangeTimes->{3.577080343170658*^9}]
}, Open  ]],

Cell[TextData[{
 "The first part is defining the function, then the ",
 StyleBox["/@",
  FontWeight->"Bold"],
 " command applies that function to the list. This is especially useful if \
you already have a list that you want to apply a function to. For example, if \
I wanted to find out what happens when the first 10 prime numbers are squared:"
}], "Text",
 CellChangeTimes->{{3.5770803582031484`*^9, 3.577080511648491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"primes", "=", 
  RowBox[{"Prime", "[", 
   RowBox[{"Range", "[", "10", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.577080517275054*^9, 3.5770805280341296`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "3", ",", "5", ",", "7", ",", "11", ",", "13", ",", "17", ",", 
   "19", ",", "23", ",", "29"}], "}"}]], "Output",
 CellChangeTimes->{3.5770805283291593`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"#", "^", "2"}], "&"}], "/@", "primes"}]], "Input",
 CellChangeTimes->{{3.5770805322725534`*^9, 3.577080541474474*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "9", ",", "25", ",", "49", ",", "121", ",", "169", ",", "289", 
   ",", "361", ",", "529", ",", "841"}], "}"}]], "Output",
 CellChangeTimes->{3.577080541906517*^9}]
}, Open  ]],

Cell["Or, try this:", "Text",
 CellChangeTimes->{{3.577080719463271*^9, 3.5770807296242867`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"#", "^", "2"}], "&"}], "/@", 
  RowBox[{"Prime", "/@", 
   RowBox[{"Range", "[", "10", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.577080745225847*^9, 3.577080753497674*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "9", ",", "25", ",", "49", ",", "121", ",", "169", ",", "289", 
   ",", "361", ",", "529", ",", "841"}], "}"}]], "Output",
 CellChangeTimes->{3.577080753716696*^9}]
}, Open  ]],

Cell[TextData[{
 "Remember, in ",
 StyleBox["Mathematica,",
  FontSlant->"Italic"],
 " and in programming in general, that there is always more than one way of \
doing something. Use methods you feel comfortable with. "
}], "Text",
 CellChangeTimes->{{3.57708065254958*^9, 3.5770807042797527`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Questions", "Subsection",
 CellChangeTimes->{{3.577080551570483*^9, 3.5770805555218782`*^9}}],

Cell[CellGroupData[{

Cell["Question 1", "Subsubsection",
 CellChangeTimes->{{3.5770805644667726`*^9, 3.5770805720185275`*^9}}],

Cell[TextData[{
 "Construct a ",
 StyleBox["Pure Function ",
  FontWeight->"Bold"],
 "which finds out if a number is divisible by 7. Use it to find out if 192988 \
is divisible by 7."
}], "Text",
 CellChangeTimes->{{3.5770806141807437`*^9, 3.5770806442127466`*^9}, {
  3.577080794234747*^9, 3.577080812123536*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5770808153028536`*^9, 3.577080816331957*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 2", "Subsubsection",
 CellChangeTimes->{{3.577080820219345*^9, 3.577080824059729*^9}}],

Cell[TextData[{
 "Use ",
 StyleBox["Select[ ] ",
  FontWeight->"Bold"],
 "with a suitable ",
 StyleBox["Pure Function",
  FontWeight->"Bold"],
 " to make a list of all the numbers under 500 which are divisible by 7. Save \
this as the variable ",
 StyleBox["sevens",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.5770808271640396`*^9, 3.577080929295252*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5770809318025026`*^9, 3.577080932687591*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 3", "Subsubsection",
 CellChangeTimes->{{3.577081038861207*^9, 3.5770810706443853`*^9}}],

Cell[TextData[{
 "Apply a ",
 StyleBox["Pure Function ",
  FontWeight->"Bold"],
 "to the list ",
 StyleBox["sevens, ",
  FontWeight->"Bold"],
 "to apply the function ",
 StyleBox["4x^2-x/2 ",
  FontWeight->"Bold"],
 "to these numbers"
}], "Text",
 CellChangeTimes->{{3.5770810733166523`*^9, 3.577081150439364*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5770811598263025`*^9, 3.577081160648385*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 4", "Subsubsection",
 CellChangeTimes->{{3.5770811636556854`*^9, 3.577081165639884*^9}}],

Cell["\<\
The ages of some people are given below. Find out if any of them give a prime \
number when put into the function 4x^3+17:\
\>", "Text",
 CellChangeTimes->{{3.5770812143377533`*^9, 3.5770812560576525`*^9}, {
  3.5770812910956526`*^9, 3.577081334868653*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ages", "=", 
  RowBox[{"{", 
   RowBox[{
   "23", ",", "45", ",", "23", ",", "12", ",", "13", ",", "45", ",", "92"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.577081192129533*^9, 3.577081210026322*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "23", ",", "45", ",", "23", ",", "12", ",", "13", ",", "45", ",", "92"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.577081337374653*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.5770813420146527`*^9, 3.577081343844653*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 5 (**)", "Subsubsection",
 CellChangeTimes->{{3.577081372954653*^9, 3.5770813840176525`*^9}, {
  3.5770815002816525`*^9, 3.5770815046656528`*^9}}],

Cell[TextData[{
 "Make a list of the top 20 most populated countries in the world, with their \
populations. Hint: Use the help to search for ",
 StyleBox["CountryData.",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.5770814360866528`*^9, 3.577081524200653*^9}, {
  3.577081567776653*^9, 3.577081617618653*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.577081387513653*^9, 3.577081388945653*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question 6 (*)", "Subsubsection",
 CellChangeTimes->{{3.577081636736653*^9, 3.5770816453126526`*^9}}],

Cell["\<\
Using a similar techniques, show me the maps of the 10 largest countries in \
the world.\
\>", "Text",
 CellChangeTimes->{{3.5770816526566525`*^9, 3.5770816931496525`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.577081695478653*^9, 3.5770816960936527`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{707, 817},
WindowMargins->{{407, Automatic}, {Automatic, 14}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (November 20, 2012)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 99, 1, 90, "Title"],
Cell[CellGroupData[{
Cell[703, 27, 100, 1, 43, "Subsection"],
Cell[806, 30, 358, 8, 68, "Text"],
Cell[1167, 40, 239, 6, 31, "Input"],
Cell[CellGroupData[{
Cell[1431, 50, 128, 2, 31, "Input"],
Cell[1562, 54, 73, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1672, 60, 128, 2, 31, "Input"],
Cell[1803, 64, 74, 1, 31, "Output"]
}, Open  ]],
Cell[1892, 68, 555, 15, 87, "Text"],
Cell[2450, 85, 296, 7, 31, "Input"],
Cell[2749, 94, 404, 11, 68, "Text"],
Cell[CellGroupData[{
Cell[3178, 109, 234, 7, 31, "Input"],
Cell[3415, 118, 75, 1, 31, "Output"]
}, Open  ]],
Cell[3505, 122, 181, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[3711, 131, 110, 1, 34, "Subsubsection"],
Cell[3824, 134, 534, 12, 68, "Text"],
Cell[4361, 148, 241, 6, 31, "Input"],
Cell[4605, 156, 158, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[4788, 165, 189, 4, 31, "Input"],
Cell[4980, 171, 331, 7, 52, "Output"]
}, Open  ]],
Cell[5326, 181, 205, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[5556, 190, 297, 9, 31, "Input"],
Cell[5856, 201, 355, 7, 52, "Output"]
}, Open  ]],
Cell[6226, 211, 376, 10, 68, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6639, 226, 122, 1, 34, "Subsubsection"],
Cell[6764, 229, 177, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[6966, 237, 150, 3, 31, "Input"],
Cell[7119, 242, 210, 5, 31, "Output"]
}, Open  ]],
Cell[7344, 250, 398, 10, 68, "Text"],
Cell[CellGroupData[{
Cell[7767, 264, 312, 9, 31, "Input"],
Cell[8082, 275, 232, 5, 31, "Output"]
}, Open  ]],
Cell[8329, 283, 146, 3, 30, "Text"],
Cell[8478, 288, 253, 7, 31, "Input"],
Cell[CellGroupData[{
Cell[8756, 299, 157, 3, 31, "Input"],
Cell[8916, 304, 256, 5, 31, "Output"]
}, Open  ]],
Cell[9187, 312, 215, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[9427, 322, 272, 8, 31, "Input"],
Cell[9702, 332, 230, 5, 31, "Output"]
}, Open  ]],
Cell[9947, 340, 426, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[10398, 352, 188, 4, 31, "Input"],
Cell[10589, 358, 210, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10836, 368, 165, 4, 31, "Input"],
Cell[11004, 374, 216, 5, 31, "Output"]
}, Open  ]],
Cell[11235, 382, 97, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[11357, 387, 220, 6, 31, "Input"],
Cell[11580, 395, 216, 5, 31, "Output"]
}, Open  ]],
Cell[11811, 403, 298, 7, 49, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12158, 416, 99, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[12282, 421, 105, 1, 34, "Subsubsection"],
Cell[12390, 424, 314, 8, 49, "Text"],
Cell[12707, 434, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12838, 440, 101, 1, 34, "Subsubsection"],
Cell[12942, 443, 374, 13, 49, "Text"],
Cell[13319, 458, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13450, 464, 103, 1, 34, "Subsubsection"],
Cell[13556, 467, 314, 12, 30, "Text"],
Cell[13873, 481, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14004, 487, 103, 1, 34, "Subsubsection"],
Cell[14110, 490, 267, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[14402, 499, 230, 6, 31, "Input"],
Cell[14635, 507, 178, 5, 31, "Output"]
}, Open  ]],
Cell[14828, 515, 94, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14959, 521, 161, 2, 34, "Subsubsection"],
Cell[15123, 525, 321, 7, 49, "Text"],
Cell[15447, 534, 92, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15576, 540, 107, 1, 34, "Subsubsection"],
Cell[15686, 543, 182, 4, 30, "Text"],
Cell[15871, 549, 94, 1, 31, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
